=============================
:code:`Trakt['sync/ratings']`
=============================

.. automodule:: trakt.interfaces.sync.ratings

  .. autoclass:: SyncRatingsInterface
    :members: add, episodes, flags, get, movies, remove, seasons, shows
    :undoc-members:
